CardInfo class

Constructors

CardInfo({required String bin, required String lastFourDigits, String? expiryYear, String? expiryMonth})

Properties

bin String
final
expiryMonth String?
final
expiryYear String?
final
hashCode int
The hash code for this object.
no setterinherited
lastFourDigits String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited