EventAddress class

Constructors

EventAddress({String? locale, String? countryCode, String? countryName, String? state, String? city, String? neighborhood, String? number, String? street, String? postalCode, String? addressLine, double? latitude, double? longitude})

Properties

addressLine → String?
final
city → String?
final
countryCode → String?
final
countryName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
latitude → double?
final
locale → String?
final
longitude → double?
final
neighborhood → String?
final
number → String?
final
postalCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final
street → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited