IncogniaFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IncogniaFlutterPlatform
Implementers

Constructors

IncogniaFlutterPlatform()
Constructs a IncogniaFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAccountId() → Future<void>
generateRequestTokenWithStatus([RequestTokenOptions? requestTokenOptions]) → Future<RequestTokenWithStatus?>
initSdk() → Future<void>
initSdkWithOptions(IncogniaOptions options) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshLocation() → Future<void>
reportBusinessUnitId(String businessUnitId) → Future<void>
sendCustomEvent(CustomEvent event) → Future<void>
sendLoginEvent(LoginEvent event) → Future<void>
sendOnboardingEvent(OnboardingEvent event) → Future<void>
sendPaymentEvent(PaymentEvent event) → Future<void>
setAccountId(String accountId) → Future<void>
setLocationEnabled(bool enabled) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ IncogniaFlutterPlatform
The default instance of IncogniaFlutterPlatform to use.
getter/setter pair