AndroidOptions class

Constructors

AndroidOptions({required String appId, bool logEnabled = false, bool locationEnabled = true, bool backgroundWakeUpEnabled = false, bool installedAppsCollectionEnabled = false, int? requestTokenMaxLength})

Properties

appId → String
final
backgroundWakeUpEnabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
installedAppsCollectionEnabled → bool
final
locationEnabled → bool
final
logEnabled → bool
final
requestTokenMaxLength → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited