OnboardingEvent class
Constructors
-
OnboardingEvent({String? accountId, String? externalId, String? tag, String? status, EventAddress? address, Map<
String, Object> ? properties})
Properties
- accountId → String?
-
final
- address → EventAddress?
-
final
- externalId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, Object> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- tag → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited