PaymentCoupon class

Constructors

PaymentCoupon({required String type, double? value, double? maxDiscount, String? id, String? name})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
final
maxDiscount double?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
value double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fixedValueType → const String
percentOffType → const String