PaymentEvent class

Constructors

PaymentEvent({required String accountId, String? externalId, String? storeId, String? tag, String? status, PaymentValue? paymentValue, PaymentCoupon? paymentCoupon, List<PaymentMethod>? paymentMethods, EventLocation? location, List<PaymentAddress>? addresses, Map<String, Object>? properties})

Properties

accountId → String
final
addresses → List<PaymentAddress>?
final
externalId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
location → EventLocation?
final
paymentCoupon → PaymentCoupon?
final
paymentMethods → List<PaymentMethod>?
final
paymentValue → PaymentValue?
final
properties → Map<String, Object>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
storeId → String?
final
tag → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited