PaymentValue class
Constructors
- PaymentValue({required double amount, String? currency, int? installments, double? discountAmount})
Properties
- amount → double
-
final
- currency → String?
-
final
- discountAmount → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installments → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited