RequestTokenStatus enum

Inheritance
Available extensions

Values

sdkNotInitialized → const RequestTokenStatus
const RequestTokenStatus('sdk_not_initialized')
tokenCallSyncOnMainThread → const RequestTokenStatus
const RequestTokenStatus('token_call_sync_on_main_thread')
timeout → const RequestTokenStatus
const RequestTokenStatus('timeout')
internalError → const RequestTokenStatus
const RequestTokenStatus('internal_error')
success → const RequestTokenStatus
const RequestTokenStatus('success')
dataCollectionDisabled → const RequestTokenStatus
const RequestTokenStatus('data_collection_disabled')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromName(String name) → RequestTokenStatus

Constants

values → const List<RequestTokenStatus>
A constant List of the values in this enum, in order of their declaration.