PaymentMethod class
Constructors
Properties
- brand → String?
-
final
- creditCardInfo → CardInfo?
-
final
- debitCardInfo → CardInfo?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- americanExpressBrand → const String
- applePayType → const String
- argencardBrand → const String
- cabalBrand → const String
- creditCardType → const String
- debitCardType → const String
- googlePayType → const String
- mastercardBrand → const String
- mealVoucherType → const String
- nuPayType → const String
- pixType → const String
- tarjetaNaranjaBrand → const String
- visaBrand → const String